<!DOCTYPE html>
<html lang="fr">
<head>
  <meta charset="UTF-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1.0"/>
  <title>Register - Andev Web</title>
      {% load static %}
  <link rel="stylesheet" href="{% static 'formulaire_app/style.css' %}">
</head>
<body>
  <canvas id="matrixCanvas"></canvas>
  <section>
    <div class="signin">
      <div class="content">
        <h2>Créer un compte</h2>
        <form method="post" class="form">
          {% csrf_token %}
          <div class="inputBox">
            {{ form.username }}
            <i>Nom d'utilisateur</i>
          </div>
          <div class="inputBox">
            {{ form.first_name }}
            <i>Prénom</i>
          </div>
          <div class="inputBox">
            {{ form.last_name }}
            <i>Nom</i>
          </div>
          <div class="inputBox">
            {{ form.email }}
            <i>Email</i>
          </div>
          <div class="inputBox">
            {{ form.date_naissance }}
            <i>Date de naissance</i>
          </div>
          <div class="inputBox">
            {{ form.password1 }}
            <i>Mot de passe</i>
          </div>
          <div class="inputBox">
            {{ form.password2 }}
            <i>Confirmer le mot de passe</i>
          </div>
          <div class="links">
            <a href="{% url 'login' %}">Se connecter</a>
          </div>
          <div class="inputBox">
            <input type="submit" value="Créer un compte">
          </div>
        </form>
      </div>
    </div>
  </section>
  <script src="{% static 'formulaire_app/script.js' %}"></script>
</body>
</html>
